#!/usr/bin/python

# Copyright (c) 2016, Daniel Nunes
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
# following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following
# disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following
# disclaimer in the documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


from __future__ import print_function
from __future__ import absolute_import
import argparse
from . import __version__, uploadfile


def main():
    """
    usage: uguu [-h] [-n NAME | -r] [--version] path_to_file

    Upload files to uguu.se from the command line.

    positional arguments:
      path_to_file          path to the file to be uploaded.

    optional arguments:
      -h, --help            show this help message and exit
      -n NAME, --name NAME  upload with a custom filename. (Don't forget the extension!)
      -r, --random          upload with a random name.
      --version             show program's version number and exit
    """
    parser = argparse.ArgumentParser(description="Upload files to uguu.se from the command line.")

    group = parser.add_mutually_exclusive_group()
    group.add_argument("-n", "--name", default="", help="upload with a custom filename. (Don't forget the extension!)")
    group.add_argument("-r", "--random", action="store_true", help="upload with a random name.")

    parser.add_argument("path_to_file", help="path to the file to be uploaded.")
    parser.add_argument("--version", action="version", version=__version__)

    args = parser.parse_args()

    url = uploadfile(args.path_to_file, name=args.name, random_name=args.random)
    if url == "":
        print("Failed upload, check your internet connection.")
        return 1
    else:
        print(url)
        return 0
