from builtins import str
import uguuAPI, pytest, mock


def upload(mock_post, mock_open, tmpdir, random=False, name=""):
    temp_file = tmpdir.join('foo.txt')
    temp_file.write("something random")

    mock_response = mock.Mock()
    expected_response = "https://a.uguu.se/okpozq_%s" % temp_file
    mock_response.content = expected_response
    mock_response.status_code = 200

    url = 'https://uguu.se/api.php?d=upload-tool'
    file_to_upload = str(temp_file)
    if random:
        randomn = "a"
    else:
        randomn = ""

    mock_post.return_value = mock_response

    with open(file_to_upload) as f01:
        mock_open.return_value = mock.MagicMock(spec=f01)

    actual_response = uguuAPI.uploadfile(file_to_upload, random_name=random, name=name)

    with mock_open(file_to_upload, 'w') as f02:
        mock_post.assert_called_once_with(url, data={'randomname': randomn, 'name': name}, files={'file': f02})

    assert actual_response == expected_response


@mock.patch('uguuAPI.open')
@mock.patch('uguuAPI.requests.post')
def test_normal_upload(mock_post, mock_open, tmpdir):
    upload(mock_post, mock_open, tmpdir)


@mock.patch('uguuAPI.open')
@mock.patch('uguuAPI.requests.post')
def test_custom_upload(mock_post, mock_open, tmpdir):
    name = "lol.rst"
    upload(mock_post, mock_open, tmpdir, name=name)


@mock.patch('uguuAPI.open')
@mock.patch('uguuAPI.requests.post')
def test_random_upload(mock_post, mock_open, tmpdir):
    random = True
    upload(mock_post, mock_open, tmpdir, random=random)


@mock.patch('uguuAPI.open')
@mock.patch('uguuAPI.requests.post')
def test_both_upload(mock_post, mock_open, tmpdir):
    name = "lol.rst"
    random = True
    with pytest.warns(UserWarning):
        upload(mock_post, mock_open, tmpdir, name=name, random=random)
